aboutsummaryrefslogtreecommitdiffstats
path: root/test/libjulia/MainFunction.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/libjulia/MainFunction.cpp')
-rw-r--r--test/libjulia/MainFunction.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/libjulia/MainFunction.cpp b/test/libjulia/MainFunction.cpp
index c26b002d..e7263d13 100644
--- a/test/libjulia/MainFunction.cpp
+++ b/test/libjulia/MainFunction.cpp
@@ -16,7 +16,7 @@
*/
/**
* @date 2018
* Unit tests for the Julia MainFunction transformation.
*/
#include <test/libjulia/Common.h>
@@ -45,7 +45,7 @@ do\
}\
while(false)
-BOOST_AUTO_TEST_SUITE(JuliaMainFunction)
+BOOST_AUTO_TEST_SUITE(YulMainFunction)
BOOST_AUTO_TEST_CASE(smoke_test)
{
@@ -16,7 +16,7 @@
/**
* @date 2018
- * Unit tests for the Julia MainFunction transformation.
+ * Unit tests for the Yul MainFunction transformation.
*/
#include <test/libjulia/Common.h>